@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2011-2021, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2011-2023, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -106,13 +106,13 @@ LocPopSum::tally_fixed_pos(const CSLocus *cloc, Datum const*const* d, LocSum *s,
     s->nucs[pos].reset();
 
     for (uint i = start; i <= end; i++) {
-        if (d[i] == NULL || pos >= d[i]->len)
+        if (d[i] == NULL || pos >= d[i]->len || d[i]->model[pos] == 'U')
             continue;
         //
         // Before counting this individual, make sure the model definitively called this
-        // position as hEterozygous or hOmozygous.
+        // position as hOmozygous.
         //
-        assert(d[i]->model[pos] != 'E');
+        assert(d[i]->model[pos] == 'O');
         num_indv++;
         p_nuc = cloc->con[pos];
     }
@@ -471,7 +471,7 @@ LocPopSum::log_hwp_pr(double n_fac, double p_fac, double q_fac, double pp, doubl
 int
 LocPopSum::tally_metapop(const CSLocus *cloc)
 {
-    int       variable_pop;
+    int16_t   variable_pop;
     uint16_t  p_cnt, q_cnt, col;
     LocSum  **s  = this->_per_pop;
     LocTally *mp = this->_meta_pop;
@@ -553,7 +553,16 @@ LocPopSum::tally_metapop(const CSLocus *cloc)
                 if (s[j]->nucs[col].p_nuc() == mp->nucs[col].q_allele ||
                     s[j]->nucs[col].q_nuc() == mp->nucs[col].q_allele)
                     variable_pop = j;
-        }
+        } else if (p_cnt == 1 && q_cnt == 1) {
+	    //
+	    // This is a special case where there are only two populations
+	    // with fixed, different alleles. Here both alleles are private
+	    // but we can't store both populations, so we will store the max
+	    // integer value instead.
+	    //
+	    if (mp->nucs[col].pop_cnt == 2)
+		variable_pop = two_priv_alleles;
+	}
         mp->nucs[col].priv_allele = variable_pop;
     }
 
@@ -566,13 +575,17 @@ LocPopSum::tally_ref_alleles(int snp_index, uint16_t &allele_cnt,
                              uint16_t &p_cnt, uint16_t &q_cnt)
 {
     int  nucs[4] = {0};
-    char nuc[2];
+    char nuc[2]  = {0};
 
     p_allele   = 0;
     q_allele   = 0;
     allele_cnt = 0;
 
     for (uint j = 0; j < this->_pop_cnt; j++) {
+
+	if (this->_per_pop[j]->nucs[snp_index].num_indv() == 0)
+	    continue;
+	
         nuc[0] = 0;
         nuc[1] = 0;
         nuc[0] = this->_per_pop[j]->nucs[snp_index].p_nuc();
@@ -614,6 +627,12 @@ LocPopSum::tally_ref_alleles(int snp_index, uint16_t &allele_cnt,
         return 0;
     }
 
+    if (allele_cnt == 0) {
+	p_allele = 0;
+        q_allele = 0;
+        return 1;
+    }
+    
     //
     // Record which nucleotide is the P allele and which is the Q allele.
     //
@@ -661,6 +680,10 @@ LocPopSum::tally_ref_alleles(int snp_index, uint16_t &allele_cnt,
     q_cnt = 0;
 
     for (uint j = 0; j < this->_pop_cnt; j++) {
+
+	if (this->_per_pop[j]->nucs[snp_index].num_indv() == 0)
+	    continue;
+	
         nuc[0] = 0;
         nuc[1] = 0;
         nuc[0] = this->_per_pop[j]->nucs[snp_index].p_nuc();
@@ -765,9 +788,11 @@ LocPopSum::haplotype_diversity(int start, int end, Datum const*const* d)
     //
     // If this haplotype is fixed, don't calculate any statistics.
     //
-    if (n == 0)
+    if (n == 0) {
+	delete lstat;
         return NULL;
-
+    }
+    
     //
     // Store a summary of the haplotype counts to output below.
     //
