@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2011-2022, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2011-2023, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -319,7 +319,7 @@ initialize_counters(map<string, long> &counter)
     counter["retained"]     = 0;
     counter["recovered"]    = 0;
     counter["transposed"]   = 0;
-
+    counter["proppair"]     = 0;
     return 0;
 }
 
@@ -339,6 +339,7 @@ consolidate_counters(map<string, long> &counter,
 	counter["retained"]     += cntr["retained"];
 	counter["recovered"]    += cntr["recovered"];
 	counter["transposed"]   += cntr["transposed"];
+	counter["proppair"]     += cntr["proppair"];
     }
 
     return 0;
@@ -358,11 +359,13 @@ consolidate_barcode_logs(map<BarcodePair, map<string, long>> &barcode_log,
 		barcode_log[bc]["total"]    = 0;
 		barcode_log[bc]["low_qual"] = 0;
 		barcode_log[bc]["retained"] = 0;
+		barcode_log[bc]["proppair"] = 0;
 	    }
 	    barcode_log[bc]["noradtag"] += it->second["noradtag"];
 	    barcode_log[bc]["total"]    += it->second["total"];
 	    barcode_log[bc]["low_qual"] += it->second["low_qual"];
 	    barcode_log[bc]["retained"] += it->second["retained"];
+	    barcode_log[bc]["proppair"] += it->second["proppair"];
 	}
     }
 
@@ -534,6 +537,9 @@ process_paired_reads(string prefix_1,
         int result_2 = 1;
 
         if (r_1->retain && r_2->retain) {
+	    counter["proppair"]++;
+	    barcode_log[bc]["proppair"]++;
+	    
             if (retain_header) {
                 result_1 = (out_file_type == FileT::fastq || out_file_type == FileT::gzfastq) ?
                     write_fastq(pair_1_fhs[bc], s_1, r_1) :
@@ -1021,6 +1027,11 @@ process_paired_reads_parallel(string prefix_1,
 		if (r_2->retain)
 		    process_singlet(r_2, renz_2, true, blog[*bc], cntr);
 
+		if (r_1->retain && r_2->retain) {
+		    cntr["proppair"]++;
+		    blog[*bc]["proppair"]++;
+		}
+		
 		//
 		// Store the result in the output buffer for writing.
 		//
@@ -1911,6 +1922,7 @@ print_results(int argc, char **argv,
     c["ambiguous"]    = 0;
     c["noradtag"]     = 0;
     c["transposed"]   = 0;
+    c["proppair"]     = 0;
     
     //
     // Total up the individual counters
@@ -1924,6 +1936,7 @@ print_results(int argc, char **argv,
         c["noradtag"]     += it->second["noradtag"];
         c["retained"]     += it->second["retained"];
 	c["transposed"]   += it->second["transposed"];
+	c["proppair"]     += it->second["proppair"];
     }
 
     auto print_nreads = [&c] (long n, const string& legend) {
@@ -1970,8 +1983,10 @@ print_results(int argc, char **argv,
     log << "Barcode Not Found\t"     << c["ambiguous"]   << "\t" << as_percentage((double) c["ambiguous"] / c["total"]) << "\n"
         << "Low Quality\t"           << c["low_quality"] << "\t" << as_percentage((double) c["low_quality"] / c["total"]) << "\n"
         << "RAD Cutsite Not Found\t" << c["noradtag"]    << "\t" << as_percentage((double) c["noradtag"] / c["total"]) << "\n"
-        << "Retained Reads\t"        << c["retained"]    << "\t" << as_percentage((double) c["retained"] / c["total"]) << "\n"
-	<< "END total_raw_read_counts" << "\n";
+        << "Retained Reads\t"        << c["retained"]    << "\t" << as_percentage((double) c["retained"] / c["total"]) << "\n";
+    if (paired)    
+	log << "Properly Paired\t"   << c["proppair"]    << "\t" << as_percentage(((double) c["proppair"]*2.0) / c["total"]) << "\n";
+    log << "END total_raw_read_counts" << "\n";
 
     if (max_bc_size_1 == 0) return 0;
 
@@ -1997,8 +2012,11 @@ print_results(int argc, char **argv,
         << "RAD Cutsite Not Found\t"
         << "Low Quality\t"
         << "Retained Reads\t"
-	<< "Pct Retained\t"
-	<< "Pct Total Reads\n";
+	<< "Pct Retained\t";
+    if (paired)
+	log << "Properly Paired\t"
+	    << "Pct Properly Paired\t";
+    log << "Pct Total Reads\n";
 
     set<BarcodePair> barcode_list;
 
@@ -2011,13 +2029,17 @@ print_results(int argc, char **argv,
 
         if (barcode_log.count(barcodes[i]) == 0)
             log << "0\t" << "0\t" << "0\t" << "0\n";
-        else
+        else {
             log << barcode_log[barcodes[i]]["total"]    << "\t"
                 << barcode_log[barcodes[i]]["noradtag"] << "\t"
                 << barcode_log[barcodes[i]]["low_qual"] << "\t"
                 << barcode_log[barcodes[i]]["retained"] << "\t"
-		<< as_percentage((double) barcode_log[barcodes[i]]["retained"] / barcode_log[barcodes[i]]["total"]) << "\t"
-		<< as_percentage((double) barcode_log[barcodes[i]]["retained"] / c["total"]) << "\n";
+		<< as_percentage((double) barcode_log[barcodes[i]]["retained"] / barcode_log[barcodes[i]]["total"]) << "\t";
+	    if (paired)
+		log << barcode_log[barcodes[i]]["proppair"] << "\t"
+		    << as_percentage(((double) barcode_log[barcodes[i]]["proppair"]*2.0) / barcode_log[barcodes[i]]["total"]) << "\t";
+	    log << as_percentage((double) barcode_log[barcodes[i]]["retained"] / c["total"]) << "\n";
+	}
     }
 
     log << "END per_barcode_raw_read_counts" << "\n"
