@@ -8,6 +8,8 @@ using namespace std;
 //
 const char *aciI[]    = {"CGC", "CGG",        // C/CGC, AciI
                          "GCG", "CCG"};
+const char *aclI[]    = {"CGTT",              // AA/CGTT, AclI
+                         "GCAA"};
 const char *ageI[]    = {"CCGGT",             // A/CCGGT, AgeI
                          "ACCGG"};
 const char *aluI[]    = {"CT",                // AG/CT, AluI
@@ -56,6 +58,8 @@ const char *ecoRV[]   = {"ATC",               // GAT/ATC, EcoRV
                          "GAT"};
 const char *ecoT22I[] = {"TGCAT",             // A/TGCAT, EcoT22I
                          "ATGCA"};
+const char *haeII[]   = {"GCGCA", "GCGCG",    // RGCGC/Y, HaeII
+                         "TGCGC", "CGCGC"};
 const char *haeIII[]  = {"CC",                // GG/CC, HaeIII
                          "GG"};
 const char *hhaI[]    = {"GCG",               // GCG/C, HhaI
@@ -150,6 +154,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz["sgrAI"]   = sgrAI;   // CR/CCGGYG, SgrAI; R=A or G; Y=C or T
     renz["apeKI"]   = apeKI;   // G/CWGC, ApeKI; W=A or T
     renz["hindIII"] = hindIII; // A/AGCTT, HindIII
+    renz["haeII"]   = haeII;   // RGCGC/Y, HaeII
     renz["haeIII"]  = haeIII;  // GG/CC, HaeIII
     renz["dpnII"]   = dpnII;   // GATC, DpnII
     renz["sphI"]    = sphI;    // GCATG/C, SphI
@@ -183,6 +188,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz["ageI"]    = ageI;    // A/CCGGT, AgeI
     renz["rsaI"]    = rsaI;    // GT/AC, RsaI
     renz["aciI"]    = aciI;    // C/CGC, AciI
+    renz["aclI"]    = aclI;    // AA/CGTT, AclI
     renz["bfaI"]    = bfaI;    // C/TAG, BfaI
     renz["bfuCI"]   = bfuCI;   // /GATC, BfuCI
     renz["aseI"]    = aseI;    // AT/TAAT, AseI
@@ -210,6 +216,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_cnt["sgrAI"]   = 2;
     renz_cnt["apeKI"]   = 2;
     renz_cnt["hindIII"] = 1;
+    renz_cnt["haeII"]   = 2;
     renz_cnt["haeIII"]  = 1;
     renz_cnt["dpnII"]   = 1;
     renz_cnt["sphI"]    = 1;
@@ -243,6 +250,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_cnt["ageI"]    = 1;
     renz_cnt["rsaI"]    = 1;
     renz_cnt["aciI"]    = 2;
+    renz_cnt["aclI"]    = 1;
     renz_cnt["bfaI"]    = 1;
     renz_cnt["bfuCI"]   = 1;
     renz_cnt["aseI"]    = 1;
@@ -260,7 +268,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_cnt["pspXI"]   = 3;
     renz_cnt["hpyCH4IV"] = 1;
     renz_cnt["ngoMIV"]  = 1;
-    
+
     renz_len["sbfI"]    = 6;
     renz_len["pstI"]    = 5;
     renz_len["pstIshi"] = 4;
@@ -271,6 +279,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_len["apeKI"]   = 4;
     renz_len["hindIII"] = 5;
     renz_len["haeIII"]  = 2;
+    renz_len["haeII"]   = 5;
     renz_len["dpnII"]   = 4;
     renz_len["sphI"]    = 5;
     renz_len["nlaIII"]  = 4;
@@ -303,6 +312,7 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_len["ageI"]    = 5;
     renz_len["rsaI"]    = 2;
     renz_len["aciI"]    = 3;
+    renz_len["aclI"]    = 4;
     renz_len["bfaI"]    = 3;
     renz_len["bfuCI"]   = 4;
     renz_len["aseI"]    = 4;
